Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(677)

Unified Diff: chrome/browser/chromeos/login/screens/app_launch_splash_screen_view.h

Issue 2700303002: cros: Unify oobe View/Actor naming to just View. (Closed)
Patch Set: Rebase Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/login/screens/app_launch_splash_screen_view.h
diff --git a/chrome/browser/chromeos/login/screens/app_launch_splash_screen_actor.h b/chrome/browser/chromeos/login/screens/app_launch_splash_screen_view.h
similarity index 92%
rename from chrome/browser/chromeos/login/screens/app_launch_splash_screen_actor.h
rename to chrome/browser/chromeos/login/screens/app_launch_splash_screen_view.h
index 271632159701b7a722d7df55760ad4893f3b2d65..d7dcfe87244a20894f22cde58d2eafe19fd96576 100644
--- a/chrome/browser/chromeos/login/screens/app_launch_splash_screen_actor.h
+++ b/chrome/browser/chromeos/login/screens/app_launch_splash_screen_view.h
@@ -2,15 +2,15 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_CHROMEOS_LOGIN_SCREENS_APP_LAUNCH_SPLASH_SCREEN_ACTOR_H_
-#define CHROME_BROWSER_CHROMEOS_LOGIN_SCREENS_APP_LAUNCH_SPLASH_SCREEN_ACTOR_H_
+#ifndef CHROME_BROWSER_CHROMEOS_LOGIN_SCREENS_APP_LAUNCH_SPLASH_SCREEN_VIEW_H_
+#define CHROME_BROWSER_CHROMEOS_LOGIN_SCREENS_APP_LAUNCH_SPLASH_SCREEN_VIEW_H_
#include "base/strings/string16.h"
namespace chromeos {
// Interface for UI implemenations of the ApplaunchSplashScreen.
-class AppLaunchSplashScreenActor {
+class AppLaunchSplashScreenView {
public:
enum AppLaunchState {
APP_LAUNCH_STATE_LOADING_AUTH_FILE,
@@ -41,9 +41,9 @@ class AppLaunchSplashScreenActor {
virtual ~Delegate() {}
};
- virtual ~AppLaunchSplashScreenActor() {}
+ virtual ~AppLaunchSplashScreenView() {}
- // Sets screen this actor belongs to.
+ // Sets screen this view belongs to.
virtual void SetDelegate(Delegate* screen) = 0;
// Shows the contents of the screen.
@@ -67,4 +67,4 @@ class AppLaunchSplashScreenActor {
} // namespace chromeos
-#endif // CHROME_BROWSER_CHROMEOS_LOGIN_SCREENS_APP_LAUNCH_SPLASH_SCREEN_ACTOR_H_
+#endif // CHROME_BROWSER_CHROMEOS_LOGIN_SCREENS_APP_LAUNCH_SPLASH_SCREEN_VIEW_H_

Powered by Google App Engine
This is Rietveld 408576698